@@ -321,10 +321,6 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=StreamFinder-Bitchute>
 
 L<http://annocpan.org/dist/StreamFinder-Bitchute>
 
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/StreamFinder-Bitchute>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/StreamFinder-Bitchute/>
@@ -450,7 +446,7 @@ sub new
 		my $no_wget = system('wget','-V');
 		unless ($no_wget) {
 			print STDERR "\n..trying wget...\n"  if ($DEBUG);
-			$html = `wget -t 2 -T 20 -O- -o /dev/null \"$url2fetch\" 2>/dev/null `;
+			$html = `wget -t 2 -T 20 -O- -o /dev/null "$url2fetch" 2>/dev/null `;
 		}
 	}
 	if ($url2fetch =~ m#\/channel\/#) {  #WE'RE A CHANNEL PAGE, GRAB 1ST VIDEO!:
@@ -475,7 +471,7 @@ sub new
 					my $no_wget = system('wget','-V');
 					unless ($no_wget) {
 						print STDERR "\n..trying wget...\n"  if ($DEBUG);
-						$html = `wget -t 2 -T 20 -O- -o /dev/null \"$url2fetch\" 2>/dev/null `;
+						$html = `wget -t 2 -T 20 -O- -o /dev/null "$url2fetch" 2>/dev/null `;
 					}
 				}
 				return undef  unless ($html);
@@ -623,7 +619,7 @@ sub new
 	foreach my $i (qw(description title artist genre)) {
 		$self->{$i} = HTML::Entities::decode_entities($self->{$i});
 		$self->{$i} = uri_unescape($self->{$i});
-		$self->{$i} =~ s/(?:\%|\\?u?00)([0-9A-Fa-f]{2})/chr(hex($1))/egso;
+		$self->{$i} =~ s/(?:\%|\\[ux\%]?00|\bu00)([0-9A-Fa-f]{2})/chr(hex($1))/egs;
 	}
 	$self->{'imageurl'} = $self->{'iconurl'};
 	$self->{'total'} = $self->{'cnt'};
